@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: dpm_main.c,v $ $Revision: 4213 $ $Date: 2011-03-22 14:15:34 +0100 (Tue, 22 Mar 2011) $ CERN IT-GD/CT Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: dpm_main.c,v $ $Revision: 4684 $ $Date: 2011-07-27 16:49:24 +0200 (Wed, 27 Jul 2011) $ CERN IT-GD/CT Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <signal.h>
@@ -21,6 +21,7 @@ static char sccsid[] = "@(#)$RCSfile: dpm_main.c,v $ $Revision: 4213 $ $Date: 20
 #endif
 #include "Cgrp.h"
 #include "Cinit.h"
+#include "Clogit.h"
 #include "Cnetdb.h"
 #include "Cpool_api.h"
 #include "Cpwd.h"
@@ -44,19 +45,13 @@ static char sccsid[] = "@(#)$RCSfile: dpm_main.c,v $ $Revision: 4213 $ $Date: 20
 #define MAX_LISTEN_SOCKS        16
 
 int being_shutdown;
-char db_name[33];
-char db_pwd[33];
-char db_srvr[33];
-char db_user[33];
 gid_t dpm_gid;
 struct dpm_srv_thread_info *dpm_srv_thread_info;
 uid_t dpm_uid;
 char dpnshost[CA_MAXHOSTNAMELEN+1];
 char func[16];
-int jid;
 char localdomain[CA_MAXHOSTNAMELEN+1];
 char localhost[CA_MAXHOSTNAMELEN+1];
-char logfile[CA_MAXPATHLEN+1];
 int maxfds;
 int nbfthreads = DPM_NBFTHREADS;
 int nbsthreads = DPM_NBSTHREADS;
@@ -214,12 +209,10 @@ dpm_main(main_args)
 struct main_args *main_args;
 {
 	int c;
-	FILE *cf;
-	char cfbuf[80];
 	struct dpm_dbfd dbfd;
 	void *doit(void *);
 	char *dp;
-	char dpmconfigfile[CA_MAXPATHLEN+1];
+	char *dpmconfigfile = NULL;
 	struct sockaddr_storage from;
 	int fromlen;
 	char *getconfent();
@@ -231,7 +224,6 @@ struct main_args *main_args;
 	int ms_tid;
 	int on = 1;	/* for REUSEADDR and IPV6_V6ONLY */
 	char *p;
-	char *p_n, *p_p, *p_s, *p_u;
 	void *pooladdr;
 	struct passwd *pw;
 	fd_set readfd, readmask;
@@ -246,10 +238,8 @@ struct main_args *main_args;
 	int thread_index;
 	struct timeval timeval;
 
-	jid = getpid();
 	strcpy (func, "dpm_serv");
-	dpmconfigfile[0] = '\0';
-	strcpy (logfile, LOGFILE);
+	Cinitlog ("dpm", LOGFILE);
 
 	/* process command line options if any */
 
@@ -262,12 +252,13 @@ struct main_args *main_args;
 			listen_ipv6only++;
 			break;
 		case 'c':
-			strncpy (dpmconfigfile, optarg, sizeof(dpmconfigfile));
-			dpmconfigfile[sizeof(dpmconfigfile) - 1] = '\0';
+			dpmconfigfile = optarg;
 			break;
 		case 'l':
-			strncpy (logfile, optarg, sizeof(logfile));
-			logfile[sizeof(logfile) - 1] = '\0';
+			if (Cinitlog ("dpm", optarg) < 0) {
+				dpmlogit (func, "Invalid logfile: %s\n", optarg);
+				exit (USERR);
+			}
 			break;
 		case 't':
 			if ((nbfthreads = strtol (optarg, &dp, 10)) < 0 ||
@@ -288,6 +279,10 @@ struct main_args *main_args;
 		}
 	}
 
+	if (nbfthreads + nbsthreads + 2 >= DPM_MAXNBTHREADS) {
+		dpmlogit (func, "Too many fast/slow threads\n");
+		return (USERR);
+	}
 	if (listen_ipv4only && listen_ipv6only) {
 		dpmlogit (func, "Can not choose to listen for only IPv4 and "
 			"also only for IPv6\n");
@@ -335,32 +330,8 @@ struct main_args *main_args;
 
 	/* get DB login info from the Disk Pool Manager server config file */
 
-	if (! *dpmconfigfile) {
-		if (strncmp (DPMCONFIG, "%SystemRoot%\\", 13) == 0 &&
-		    (p = getenv ("SystemRoot")))
-			sprintf (dpmconfigfile, "%s%s", p, strchr (DPMCONFIG, '\\'));
-		else
-			strcpy (dpmconfigfile, DPMCONFIG);
-	}
-	if ((cf = fopen (dpmconfigfile, "r")) == NULL) {
-		dpmlogit (func, DP023, dpmconfigfile);
+	if (dpm_get_dbconf (dpmconfigfile) < 0)
 		return (CONFERR);
-	}
-	if (fgets (cfbuf, sizeof(cfbuf), cf) &&
-	    strlen (cfbuf) >= 5 && (p_u = strtok (cfbuf, "/\n")) &&
-	    (p_p = strtok (NULL, "@\n")) && (p_s = strtok (NULL, "/\n"))) {
-		if ((p_n = strtok (NULL, "\n")))
-			strcpy (db_name, p_n);
-		else
-			strcpy (db_name, "dpm_db");
-		strcpy (db_user, p_u);
-		strcpy (db_pwd, p_p);
-		strcpy (db_srvr, p_s);
-	} else {
-		dpmlogit (func, DP009, dpmconfigfile, "incorrect");
-		return (CONFERR);
-	}
-	(void) fclose (cf);
 
 	/* Initialize the request counter mutex and condition variable */
 
@@ -380,7 +351,7 @@ struct main_args *main_args;
 	(void) dpm_init_dbpkg ();
 	memset (&dbfd, 0, sizeof(dbfd));
 	dbfd.idx = nbfthreads + nbsthreads + 1;
-	if (dpm_opendb (db_srvr, db_user, db_pwd, db_name, &dbfd) < 0)
+	if (dpm_opendb (&dbfd) < 0)
 		return (SYERR);
 
 	/* Get current disk pool configuration */
@@ -795,7 +766,7 @@ gcthread(void *arg)
 	strcpy (func, "gcthread");
 	memset (&dbfd, 0, sizeof(dbfd));
 	dbfd.idx = nbfthreads + nbsthreads + 2 + gc_entry->gc_idx;
-	if (dpm_opendb (db_srvr, db_user, db_pwd, db_name, &dbfd) < 0)
+	if (dpm_opendb (&dbfd) < 0)
 		return (NULL);
 	last_db_use = time (0);
 	memset (&file_uniqueid, 0, sizeof(file_uniqueid));
@@ -948,8 +919,7 @@ struct dpm_srv_thread_info *thip;
 		if (req_type != DPM_GETPOOLS && req_type != DPM_GETPOOLFS &&
 		    req_type != DPM_GETPROTO && req_type != DPM_SHUTDOWN &&
 		    req_type != DPM_INCREQCTR && req_type != DPM_PING) {
-			if (dpm_opendb (db_srvr, db_user, db_pwd, db_name,
-			    &thip->dbfd) < 0) {
+			if (dpm_opendb (&thip->dbfd) < 0) {
 				c = serrno;
 				sendrep (thip->s, MSG_ERR, "db open error: %d\n", c);
 				sendrep (thip->s, DPM_RC, c);
@@ -1099,7 +1069,7 @@ void *arg;
 	strcpy (func, "rexthread");
 	memset (&dbfd, 0, sizeof(dbfd));
 	dbfd.idx = nbfthreads + nbsthreads;
-	if (dpm_opendb (db_srvr, db_user, db_pwd, db_name, &dbfd) < 0)
+	if (dpm_opendb (&dbfd) < 0)
 		return (NULL);
 	last_loop_time = last_db_use = time (0);
 	memset (&rec_clean, 0, sizeof(rec_clean));
