@@ -4,7 +4,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: dpm_proclreq.c,v $ $Revision: 4213 $ $Date: 2011-03-22 14:15:34 +0100 (Tue, 22 Mar 2011) $ CERN IT-GD/CT Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: dpm_proclreq.c,v $ $Revision: 4686 $ $Date: 2011-07-27 16:50:39 +0200 (Wed, 27 Jul 2011) $ CERN IT-GD/CT Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <errno.h>
@@ -32,10 +32,6 @@ static char sccsid[] = "@(#)$RCSfile: dpm_proclreq.c,v $ $Revision: 4213 $ $Date
 static struct dpm_srv_thread_info *dpm_srv_thread_info;
 static int excl_mutex;
 extern int being_shutdown;
-extern char db_name[33];
-extern char db_pwd[33];
-extern char db_srvr[33];
-extern char db_user[33];
 extern gid_t dpm_gid;
 extern uid_t dpm_uid;
 extern int nbfthreads;
@@ -163,7 +159,7 @@ void *arg;
 
 	if (! thip->db_open_done) {
 		Cns_seterrbuf (thip->errbuf, sizeof(thip->errbuf));
-		if (dpm_opendb (db_srvr, db_user, db_pwd, db_name, &thip->dbfd) < 0)
+		if (dpm_opendb (&thip->dbfd) < 0)
 			return (NULL);
 		thip->db_open_done = 1;
 		thip->last_db_use = time (0);
@@ -206,6 +202,7 @@ void *arg;
 		alloced_gids = 1;
 		if ((fqan = calloc (nbgids, sizeof(char *))) == NULL)
 			goto free_voms_info;
+		dpmlogit ("proclreq", "calling Cns_getgrpbygids\n");
 		if (Cns_getgrpbygids (nbgids, gids, fqan) < 0)
 			goto free_voms_info;
 		if ((voname = strdup (fqan[0])) == NULL)
