@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2004-2010 by CERN
+ * Copyright (C) 2004-2011 by CERN
  * All rights reserved
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)$RCSfile: srmv2_dirreq.c,v $ $Revision: 4109 $ $Date: 2011-02-15 10:32:01 +0100 (Tue, 15 Feb 2011) $ CERN Jean-Philippe Baud";
+static char sccsid[] = "@(#)$RCSfile: srmv2_dirreq.c,v $ $Revision: 4497 $ $Date: 2011-06-20 18:37:21 +0200 (Mon, 20 Jun 2011) $ CERN Jean-Philippe Baud";
 #endif /* not lint */
 
 #include <sys/stat.h>
@@ -20,10 +20,6 @@ static char sccsid[] = "@(#)$RCSfile: srmv2_dirreq.c,v $ $Revision: 4109 $ $Date
 #include "srm_server.h"
 #include "srmv2H.h"
 #define MAXLSCOUNT 5000
-extern char db_name[33];
-extern char db_pwd[33];
-extern char db_srvr[33];
-extern char db_user[33];
 extern int Cgroupmatch (gid_t, int, gid_t *);
 static int na_key = -1;
 
@@ -787,7 +783,7 @@ ns1__srmLs (struct soap *soap, struct ns1__srmLsRequest *req, struct ns1__srmLsR
 		/* Connect to the database if not done yet */
 
 		if (! thip->db_open_done) {
-			if (dpm_opendb (db_srvr, db_user, db_pwd, db_name, &thip->dbfd) < 0) {
+			if (dpm_opendb (&thip->dbfd) < 0) {
 				repp->returnStatus->statusCode = SRM_USCOREINTERNAL_USCOREERROR;
 				repp->returnStatus->explanation = soap_strdup (soap, "DB open error");
 				RETURNSC (SOAP_OK, SRM_USCOREINTERNAL_USCOREERROR);
